@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 __author__ = 'jasonxu'
-from exception import AuthErrorException
+from cthun_client.exception import AuthErrorException
 
 
 class Config:
@@ -19,8 +19,7 @@ class Config:
     @property
     def access_token(self):
         if not self._access_token:
-            pass
-            # raise AuthErrorException("auth error")
+            raise AuthErrorException("auth error")
         return self._access_token
 
     @access_token.setter
